@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: murmur-hash
-version: 0.1.0.2
-id: murmur-hash-0.1.0.2-84236d963ec095b8dd8b79cb14107413
+version: 0.1.0.5
+id: murmur-hash-0.1.0.5-16674e6b7d30714e5f6d0df21bd68c32
 
 license: BSD3
 copyright:
@@ -9,6 +9,7 @@ maintainer: Thomas Schilling <nominolo@googlemail.com>
 stability: provisional
 homepage: http://github.com/nominolo/murmur-hash
 package-url:
+synopsis: MurmurHash2 implementation for Haskell.
 description: Implements MurmurHash2, a good, fast, general-purpose,
              non-cryptographic hashing function.  See
              <http://murmurhash.googlepages.com/> for details.
@@ -21,19 +22,21 @@ pkgpath: devel/hs-murmur-hash
 exposed: True
 exposed-modules: Data.Digest.Murmur32 Data.Digest.Murmur64
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/murmur-hash-0.1.0.2
-library-dirs: /usr/local/lib/ghc/murmur-hash-0.1.0.2
-hs-libraries: HSmurmur-hash-0.1.0.2
+trusted: False
+import-dirs: /usr/local/lib/ghc/murmur-hash-0.1.0.5
+library-dirs: /usr/local/lib/ghc/murmur-hash-0.1.0.5
+hs-libraries: HSmurmur-hash-0.1.0.5
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
+depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
+         bytestring-0.9.2.1-4f95f32adc23f1bc25c472a646e99581
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-murmur-hash-0.1.0.2/html/murmur-hash.haddock
-haddock-html: /usr/local/share/doc/hs-murmur-hash-0.1.0.2/html
+haddock-interfaces: /usr/local/share/doc/hs-murmur-hash-0.1.0.5/html/murmur-hash.haddock
+haddock-html: /usr/local/share/doc/hs-murmur-hash-0.1.0.5/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
